==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/is-IS/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Sérsniðnum reitum',
    'manage'                    => 'Stjórna',
    'field'		                => 'reitur',
    'about_fieldsets_title'		=> 'Um reitasett',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Encrypt the value of this field in the database',
    'encrypt_field_help'      => 'WARNING: Encrypting a field makes it unsearchable.',
    'encrypted'      	        => 'Dulkóðað',
    'fieldset'      	        => 'Reitasett',
    'qty_fields'      	      => 'Magn Reita',
    'fieldsets'      	        => 'Reitasett',
    'fieldset_name'           => 'Nafn á Reitasetti',
    'field_name'              => 'Nafn á Reiti',
    'field_values'            => 'Gildi á Reitum',
    'field_values_help'       => 'Add selectable options, one per line. Blank lines other than the first line will be ignored.',
    'field_element'           => 'Innsláttarform',
    'field_element_short'     => 'Form',
    'field_format'            => 'Forsníð',
    'field_custom_format'     => 'Custom Regex Format',
    'field_custom_format_help'     => 'This field allows you to use a regex expression for validation. It should start with "regex:" - for example, to validate that a custom field value contains a valid IMEI (15 numeric digits), you would use <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Required',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Notað af Tegundum (Models)',
    'order'   		            => 'Röð',
    'create_fieldset'         => 'Nýtt Reitasett',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Útbúa nýtt Reitasett (Nafn)',
    'create_field'            => 'Nýr sérsniðinn reitur',
    'create_field_title' => 'Útbúa nýtt sérsniðinn reit',
    'value_encrypted'      	        => 'The value of this field is encrypted in the database. Only admin users will be able to view the decrypted value',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails',
    'show_in_email_short'     => 'Include in emails.',
    'help_text' => 'Hjápartexti',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Endurraða',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Einstakt',
    'display_in_user_view' => 'Leyfa útskráðum notanda að skoða þessi gildi á síðunni Skoða úthlutaðar eignir',
    'display_in_user_view_table' => 'Sýnileg notenda',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'Show in list views by default. Authorized users will still be able to show/hide via the column selector',
    'show_in_listview_short' => 'Show in lists',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/is-IS/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Sérsniðnum reitum',
    'manage'                    => 'Stjórna',
    'field'		                => 'reitur',
    'about_fieldsets_title'		=> 'Um reitasett',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Encrypt the value of this field in the database',
    'encrypt_field_help'      => 'WARNING: Encrypting a field makes it unsearchable.',
    'encrypted'      	        => 'Dulkóðað',
    'fieldset'      	        => 'Reitasett',
    'qty_fields'      	      => 'Magn Reita',
    'fieldsets'      	        => 'Reitasett',
    'fieldset_name'           => 'Nafn á Reitasetti',
    'field_name'              => 'Nafn á Reiti',
    'field_values'            => 'Gildi á Reitum',
    'field_values_help'       => 'Add selectable options, one per line. Blank lines other than the first line will be ignored.',
    'field_element'           => 'Innsláttarform',
    'field_element_short'     => 'Form',
    'field_format'            => 'Forsníð',
    'field_custom_format'     => 'Custom Regex Format',
    'field_custom_format_help'     => 'This field allows you to use a regex expression for validation. It should start with "regex:" - for example, to validate that a custom field value contains a valid IMEI (15 numeric digits), you would use <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Required',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Notað af Tegundum (Models)',
    'order'   		            => 'Röð',
    'create_fieldset'         => 'Nýtt Reitasett',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Útbúa nýtt Reitasett (Nafn)',
    'create_field'            => 'Nýr sérsniðinn reitur',
    'create_field_title' => 'Útbúa nýtt sérsniðinn reit',
    'value_encrypted'      	        => 'The value of this field is encrypted in the database. Only admin users will be able to view the decrypted value',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails',
    'show_in_email_short' => 'Include in emails',
    'help_text' => 'Hjápartexti',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Endurraða',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Einstakt',
    'display_in_user_view' => 'Leyfa útskráðum notanda að skoða þessi gildi á síðunni Skoða úthlutaðar eignir',
    'display_in_user_view_table' => 'Sýnileg notenda',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'Show in list views by default. Authorized users will still be able to show/hide via the column selector',
    'show_in_listview_short' => 'Show in lists',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
